function [pv,h,te]=fgraphpoints(name,xmima,ymima,plotround,rot);
%function [pv,h,te]=fgraphpoints(name,xmima,ymima,plotround,rot);
%Florian Habermacher, April 2012, SIAW-HSG
%
%fgraphpoints automatically calculates coordinates for points of prepared (24bit-bitmap) graphs:
%Prepare images by RGBcoloring:
%-point (xmin/ymin) to color [230 30 30],
%-a point xmax to color [30 230 30],
%-a point ymax to color [30 30 230].
%-and color all points whose coordinates are wanted to [254 0 0]
%
%fgraphpoints calculates coordinates for all those points, and plots them into the image
%and returns the result also numerically (pv).
%
%name is the image name (typically *.bmp),
%xmima is the minimum and maximum x-value for the given pixels, e.g. [0 100]
%ymima is the minimum and maximum y-value for the given pixels, e.g. [0 50]
%plotround [default=true] indicates whether values are shown rounded
%rot [default=0] indicates the angle for the direction (degrees and counterclockwise!) to which text is written
%
%pv returns a list of the coordinates,
%h the handle to the plotted figure
%te the handles to the coordinate-annotations in the figure

if nargin<5 rot=0;end;if nargin<4 plotround=true;end;
pv=NaN;h=NaN;te=NaN;
%xvmi=0;yvmi=0;xvma=10000;yvma=140;plotround=true;rot=-45;
xvmi=xmima(1);yvmi=ymima(1);xvma=xmima(2);yvma=ymima(2);
xymip=[230 30 30];
xmap=[30 230 30];
ymap=[30 30 230];
poi=[254 0 0];
im=permute(imread(name),[2 1 3]);
h=figure('name',fstring('fimpoints - ',name));image(permute(im,[2 1 3]));
xs=size(im,1);ys=size(im,2);
np=0;clear ps;xmi=NaN;ymi=NaN;xma=NaN;yma=NaN;
fdstatstart;
for x=1:xs,fprogress(x,xs,10);
    for y=1:ys
        if same([im(x,y,1) im(x,y,2) im(x,y,3)],xymip), xmi=x;ymi=y;end;
        if same([im(x,y,1) im(x,y,2) im(x,y,3)],xmap),xma=x;end;
        if same([im(x,y,1) im(x,y,2) im(x,y,3)],ymap),yma=y;end;
        if same([im(x,y,1) im(x,y,2) im(x,y,3)],poi),np=np+1;ps(np,:)=[x y];end;
    end;
end;
if isnan(prod([xmi ymi xma yma]))
    fdisp('Hey, problem, not all three corner points found!');
    fdisp('xmi=',xmi,',ymi=',ymi,',xma=',xma,',yma=',yma);
    fdisp('You should set following three points with following colors:');
    fdisp('xymip, RGB color: ',xymi);
    fdisp('xmap, RGB color: ',xma);
    fdisp('ymap, RGB color: ',yma);
    fdisp('Aborting..');return;
end;
if np==0, fdisp('No "points" found: set points to RGBcolor ',poi,'. Returning..');return;end;
pv=NaN(np,2);%values of points
te=NaN(np,1);%handles to text annotations
for p=1:np
    pv(p,:)=[xvmi+(xvma-xvmi)*(ps(p,1)-xmi)/(xma-xmi), yvmi+(yvma-yvmi)*(ps(p,2)-ymi)/(yma-ymi)];
    if plotround
        te(p)=text(ps(p,1),ps(p,2),fstring(round(pv(p,1)),'/',round(pv(p,2))),'rotation',rot);
    else
        te(p)=text(ps(p,1),ps(p,2),fstring(pv(p,1),'/',pv(p,2)),'rotation',rot);
    end;
end;
             