function fm=fmax(f,d);
%Florian Habermacher, Atlanta 2005

%function fm=fmax(f,d); d is optional

%Aggregates the dimension d of the field f and returns the maximum values
%f: field with dimensions [a1, a2, ..., an] with n maximum 5
%d: the dimension that has to be collapsed and of which the maximum values
%have to be taken

%fm if d is given: field with dimensions [a1, a2, ... a(d) is missing, a(n-1)]
%fm if d is not given: scalar representing the total maximum of f

dim=size(f);
numdim=size(dim,2);
if numdim>5 fdisp('Error in fmax: f has ',numdim,' dimensions. Maximum allowed is 5.');return;end;
dimstoadd=5-numdim;
for i=1:dimstoadd
    f=finsdim1(f);
end;
switch nargin
    case 2, %means d is given
        d2=d+dimstoadd;
        nd=size(f);
        %for i=1:nd(1) for j=1:nd(2) for k=1:nd(3) for l=1:nd(4)
        switch d2
            case 1, 
                fm=zeros(nd(2),nd(3),nd(4),nd(5));for j=1:nd(2) for k=1:nd(3) for l=1:nd(4) for m=1:nd(5) fm(j,k,l,m)=max(f(:,j,k,l,m));end;end;end;end;
            case 2, 
                fm=zeros(nd(1),nd(3),nd(4),nd(5));for i=1:nd(1) for k=1:nd(3) for l=1:nd(4) for m=1:nd(5) fm(i,k,l,m)=max(f(i,:,k,l,m));end;end;end;end;
            case 3, 
                fm=zeros(nd(1),nd(2),nd(4),nd(5));for i=1:nd(1) for j=1:nd(2) for l=1:nd(4) for m=1:nd(5) fm(i,j,l,m)=max(f(i,j,:,l,m));end;end;end;end;
            case 4, 
                fm=zeros(nd(1),nd(2),nd(3),nd(5));for i=1:nd(1) for j=1:nd(2) for k=1:nd(3) for m=1:nd(5) fm(i,j,k,m)=max(f(i,j,k,:,m));end;end;end;end;
            case 5, 
                fm=zeros(nd(1),nd(2),nd(3),nd(4));for i=1:nd(1) for j=1:nd(2) for k=1:nd(3) for l=1:nd(4) fm(i,j,k,l)=max(f(i,j,k,l,:));end;end;end;end;
            otherwise fdisp('Error in fmax: dimensions of field f not consistent with d');return;
        end;
        for i=1:dimstoadd
            fm=fdeldim1(fm);
        end;
    case 1, %means d is not given
        fm=max(f(:));
    otherwise fdisp('Error in fmax: must either have 1 or 2 arguments, now it'' called with ',nargin,' arguments.');
end;