function [x,y,v,inner]=fmax2d(str,xmi,xma,ymi,yma,n,tol,doplot,dowrite,figtit,globs,dosave,docontour)
% function [x,y,v]=fmax2d(str,xmi,xma,ymi,yma,n,tol,doplot (true),dowrite (true),figtit,globs,dosave (false),docontour(true));
% Florian Habermacher, SIAW-HSG, Aug 2011
%
% fmax2d searches for a maximum of what the evaluated string str returns
% for the variable v as a function of the values of the arguments x and y.
%
% xmi & xma,ymi & yma: ranges in which the maximum os to be looked for.
% Note that the algorithm may in some cases also search beyond these
% borders (not further than half of the width of the indicated range) in
% the case where maxima found in the initial runs are not close to the
% middle of this initial range.
%
% n: the # of x- and y-values for which the function is evaluated in each
% "round"; after each "round", the width of the evaluation field is divided
% by two. 
%
% tol: indicates the desired tolerance: fmax2d calculates for as many rounds
% until the distance (on the x-axis) between two neighboring evaluation-points becomes
% smaller or equal to tol 
%
% doplot (freiwillig): whether all intermediate results should be plotted as 2d-color
% plots.
%
% dowrite (freiwillig): whether and how much progress indications should be made during
% the calculations: dowrite=0 implies no indication, dowrite=1 implies that
% "rounds" are shown, dowrite=2 implies that subprogress ("lines") within
% rounds is indicated, too.
%
% figtit (freiwillig): title for the figure (only used when doplot is true...)
%
% globs (freiwillig): names (separated simply by spaces) of variables which must be declared as globals
% for being recognized inside this fmax2d function!
%  E.g. globvars='a b asdf' -> passing the string globvars as 10th argument
%  implies that the 3 variables a, b, asdf will be considered as globals
%  within the function. Obviously, for this to be sensible, you must have
%  defined these variables already as globals in the main program.
%
% dosave (freiwillig): whether Value-field results should be saved as matlab data files (named [figtit '_values']). Default is no saving (false)
% 
% docontour (freiwillig): whether contour lines are plotted as well or not. Default is to plot these lines.
%
% Returned variables:
% x & y:  Coordinates of the maximum value
% v:      maximum value,
% inner:  dummy value indicating 0 if in each iteration round
% the maximal value was strictly in the inside and 1 if it was in at least 1 round
% on the border of the calculations.
global fmax2dserialerrmax;
if nargin<13 docontour=true;end;
if nargin<12 dosave=false;end;    
if nargin>=11, eval(fstring('global ',globs,';'));end;
% % % fdisp('Globs= ',globs);
% % % xxo.val=[33 0];xxc.val=[0 0];
% % % [too,tcc,toi, tci, tot, tct, po,o,c,ot,ct,cc,XX,nyt,u,Usum,ddam,denom,xxx,E,Et,efo,efc,ol,liqgapp]=gams('oilandpeconsfinfixtaxliq2',xxo,xxc,'dam','liqcos','a','aa','b','bb','g','gr');
% % % fdisp('UUUU= ',Usum);
if nargin<10 figtit='fmax2d plot';end;if nargin<9 dowrite=true;end;if nargin<8 doplot=true;end;
if numel(fmax2dserialerrmax)==0 fmax2dserialerrmax=4;end;
if ceil(n)~=n fdisp('Attention in fmax2d: you demanded a non-integer number of  evaluation points (',n,'). n must be a positive integer and was thus automatically increased to ',ceil(n),'.');
    n=ceil(n);
end;
xrad=(xma-xmi)/2;yrad=(yma-ymi)/2;
inner=0;rnd=1;
nrnd=ceil((log((xma-xmi)/(n-1))-log(tol))/log(2));
if nrnd<1 if dowrite fdisp('Error in fmax2d: xmi (',xmi,') and xma (',xma,') too close for the indicated tol (',tol,'). Thus calculating simply only a first round.');end;
    nrnd=1;
end;
if doplot figure('Name',figtit,'NumberTitle','off');fpsetsub(nrnd);end;
times=NaN(nrnd,n,n);
tic;
for rnd=1:nrnd
    %if con xs=fv(xmi,xma,n),ys=fv(ymi,yma,n), else xs=fv(xmi,xma,n);ys=fv(ymi,yma,n);end;
    xs=fv(xmi,xma,n);ys=fv(ymi,yma,n);
    U=NaN(n,n);
    if dowrite,fdisp('Round ',rnd,'/',nrnd);end;
    for xi=1:n,x=xs(xi);if dowrite>1 fdisp(xi);end;for yi=1:n,y=ys(yi);
            times(rnd,xi,yi)=toc;tic;mustdo=true;serialerr=0;
            while mustdo,mustdo=false;
                try,eval(str);% str must be a function/command/process which uses x & y as arguments and assigns the resulting (to be maximized) value to the variable v
                catch exception
                    mustdo=true;serialerr=serialerr+1;fdisp(serialerr,fenglishnumberth(serialerr),' error (Message "',exception.message,'") in series - retrying.');
                    if serialerr>fmax2dserialerrmax
                        fdisp('Too many serial errors (',serialerr,'; only ',fmax2dserialerrmax,' are allowed) in fmax2d, evaluating "',str,'". Aborting... (increase the global variable ''fmax2dserialerrmax'' if you want the program not to stop in such situations)');
                        return;
                    end;
                end;
            end;
            %fdisp('xxxx');fdisp(U(xi,yi));too,Usum,v,fdisp(' & ',v);
            %if con if rnd==1 && xi<3 && yi<3 fdisp('xxo=',xxo.val,' xxc=',xxc.val,' v=',v,' & str=',str);end; end;
% % %             Usum
% % %             fdisp('');
% % %             v
            U(xi,yi)=v;
    end;end;Umax=U(1,1);
    for xi=1:n,for yi=1:n,if U(xi,yi)>=Umax,Umax=U(xi,yi);hxi=xi;hyi=yi;end;end;end;
    if dowrite if hxi==1||hxi==n||hyi==1||hyi==n fdisp('Attention in fmax2d: Maximal value in round ',rnd,' is at border (hxi=',hxi,', hyi=',hyi,')!');
            inner=1;
        end;
    end;
    xrad=xrad/2;yrad=yrad/2;
    xmi=xs(hxi)-xrad;xma=xs(hxi)+xrad;ymi=ys(hyi)-yrad;yma=ys(hyi)+yrad;
    if doplot,
        fpscs(rnd);pcolor(xs,ys,U');if dosave Usav{rnd}=U;end;if docontour hold on;contour(xs,ys,U',':k');end;
        line([xmi xma;xmi xma;xmi xmi;xma xma],[ymi ymi;yma yma;ymi yma;ymi yma],'LineWidth',4);
        SHADING FLAT;
    end;
end;
x=xs(hxi);y=ys(hyi);v=Umax;
if dosave, save([figtit '_values'],'Usav');end;