function scalevalues=fpscale(v1,v2,v3);
%Florian Habermacher, Atlanta 2005
%function scalevalues=fpscale(v1,v2,v3):, v2 and v3 are optional
%-> either of:
%function scalevalues=fpscale(power,numvalues,floats);
%function scalevalues=fpscale(power,numvalues);
%function scalevalues=fpscale(power);
%returns the values that correspond to colorscale applied by fplot with power, according to the min and max that were set by fpsetmm:
%if specified, a number numvalues of values are returned, otherwise 4
%values.
%if specified, the values are rounded for a number floats of digits after
%the point, otherwise the values remain unrounded (set 0 if you want
%integer values)

global fpmin fpmax;
maxfloats=15;
if size(fpmin)==[0 0]
    fpmin=0;
    fpmax=1;
    fdisp('fpscale: fpmin & fpmax set to 0 and 1.');
end;

power=v1;
if nargin>=2
    numvalues=v2;
else
    numvalues=4;
end;
if nargin>=3
    floats=v3;
else
    floats=maxfloats;
end;    
scalevalues=zeros(1,numvalues);
powmin=sign(fpmin)*abs(fpmin)^power;
powmax=sign(fpmax)*abs(fpmax)^power;
for i=1:numvalues
    value=powmin+(powmax-powmin)*(i-1)/(numvalues-1);
    scalevalues(i)=sign(value)*(abs(value))^(1/power);
end;

if floats~=maxfloats
    for i=1:numvalues
        scalevalues(i)=round(10^floats*scalevalues(i))/10^floats;
    end;
end;

