function fsaveas(h,name)
% function fsaveas(h,name): saves figure 'h' with name combined as (i) fsaveasininame and the (ii) MATLAB name of the figure (cleaned from suspicious characters such as = , \ " etc.)
%                           if fsaveasDMY is set true (default none), (iii) fDMY is added after fsaveasininama, and finally,
%                           if 'name' is passed, (iv) name is added at the end to the name.
% The figure is saved in all formats for which the extension is given in the string or cell of strings fsaveasext.
% If fsaveasreplacespace spaces in the figurename will be replaced by _ signs.
%
% Note: -To specify also resolution, at leasat for BMP TIF JPG, maybe use function fpsave
%       -To save as high resolution PNG, can use fsaveaspng
%
% Example:
%
% h=figure('name','My first figure saved with ');plot(1:10);
% global fsaveasininame fsaveasDMY fsaveasext fsaveasreplacespace;
% fsaveasininame='D:\Dropbox\GP '; fsaveasDMY=true; fsaveasext={'fig','emf'}; fsaveasreplacespace=true;
% fsaveas(gcf,'the convenient fsasveas function');
%
% Update 11May2014: saveas can randomly write black/white eps-figures instead of general color figures. Hence, now when extension is 'eps', this function automatically adds the option "epsc" which ensures it's going to be saved as color figure. Cf. http://www.mathworks.co.uk/matlabcentral/newsreader/view_thread/299897
if nargin<2 name='';end;
global fsaveasininame fsaveasDMY fsaveasext fsaveasreplacespace;
if isempty(fsaveasininame) fsaveasininame='';end;
if isempty(fsaveasDMY) fsaveasDMY=false;end;
if isempty(fsaveasext) fsaveasext={'fig','emf'};fdisp('fsaveas: fsaveasext was not defined; set to default: {''fix'',''emf''}');end;
if ischar(fsaveasext) fsaveasextcell={fsaveasext}; else fsaveasextcell=fsaveasext;end;
if isempty(fsaveasreplacespace) fsaveasreplacespace=true;fdisp('fsaveas: fsaveasreplacespace was not defined; set to true.');end;
badchars='\/:|*!?"<>';%chars=char(1:255);goodchars=['A':'Z','a':'z','0':'9','.-_'''
for i=1:numel(h), tit=get(h(i),'name');for ch=badchars tit=tit(tit~=ch);end;
  for j=1:numel(fsaveasextcell),ext=fsaveasextcell{j}, figname=fstring(fsaveasininame,fcond(fsaveasDMY,fDMY,''),tit,name,'.',ext);
    if fsaveasreplacespace, for k=1:length(figname) if double(figname(k))==32 || double(figname(k))==127 figname(k)='_';end;end;end;
    %saveas(h(i),figname);fdisp(figname);
    if strcmp(ext,'eps'),
      fdisp('is eps, so adding "epsc"-option in saveas to prevent black-white-only saving');
      saveas(h(i),figname,'epsc');fdisp(figname);
    else
      saveas(h(i),figname);fdisp(figname);
    end;
  end;
end;